==> xlniuxdata-vipgame-1.0.62-20160520.055648-6-sources.jar: com/xunlei/niux/data/vipgame/dto/game/MobileGameDTO.java <==
package com.xunlei.niux.data.vipgame.dto.game;

/**
 * 手游DTO，取sdk游戏和cps游戏的共有字段
 * Created by lizeyu on 2016/4/21.
 */
public class MobileGameDTO{
    private String gameId;
    private String gameNo;
    private String gameName;
    private String gameDesc;
    private Integer gameFeature;
    private Integer gameTheme;
    private Integer displayOrder;
    private Integer downloadNum;
    private String packageName;
    private Integer status;
    private String picUrl;
    private String smallPicUrl;
    private String mulPhotoUrl;
    private String downLoadUrl;
    private String summary;
    private String appSize;
    private String recommendIndex;
    private Integer mobileGameType;  //cps游戏中，1网游，2单机；sdk游戏，则全部是网游


    public String getGameId(){
        return gameId;
    }

    public void setGameId(String gameId){
        this.gameId = gameId;
    }

    public String getGameNo(){
        return gameNo;
    }

    public void setGameNo(String gameNo){
        this.gameNo = gameNo;
    }

    public String getGameName(){
        return gameName;
    }

    public void setGameName(String gameName){
        this.gameName = gameName;
    }

    public String getGameDesc(){
        return gameDesc;
    }

    public void setGameDesc(String gameDesc){
        this.gameDesc = gameDesc;
    }

    public Integer getGameFeature(){
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature){
        this.gameFeature = gameFeature;
    }

    public Integer getGameTheme(){
        return gameTheme;
    }

    public void setGameTheme(Integer gameTheme){
        this.gameTheme = gameTheme;
    }

    public Integer getDisplayOrder(){
        return displayOrder;
    }

    public void setDisplayOrder(Integer displayOrder){
        this.displayOrder = displayOrder;
    }

    public Integer getDownloadNum(){
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum){
        this.downloadNum = downloadNum;
    }

    public String getPackageName(){
        return packageName;
    }

    public void setPackageName(String packageName){
        this.packageName = packageName;
    }

    public Integer getStatus(){
        return status;
    }

    public void setStatus(Integer status){
        this.status = status;
    }

    public String getPicUrl(){
        return picUrl;
    }

    public void setPicUrl(String picUrl){
        this.picUrl = picUrl;
    }

    public String getSmallPicUrl(){
        return smallPicUrl;
    }

    public void setSmallPicUrl(String smallPicUrl){
        this.smallPicUrl = smallPicUrl;
    }

    public String getMulPhotoUrl(){
        return mulPhotoUrl;
    }

    public void setMulPhotoUrl(String mulPhotoUrl){
        this.mulPhotoUrl = mulPhotoUrl;
    }

    public String getDownLoadUrl(){
        return downLoadUrl;
    }

    public void setDownLoadUrl(String downLoadUrl){
        this.downLoadUrl = downLoadUrl;
    }

    public String getSummary(){
        return summary;
    }

    public void setSummary(String summary){
        this.summary = summary;
    }

    public String getAppSize(){
        return appSize;
    }

    public void setAppSize(String appSize){
        this.appSize = appSize;
    }

    public String getRecommendIndex(){
        return recommendIndex;
    }

    public void setRecommendIndex(String recommendIndex){
        this.recommendIndex = recommendIndex;
    }

    public Integer getMobileGameType(){
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType){
        this.mobileGameType = mobileGameType;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170705.060154-89-sources.jar: com/xunlei/niux/data/vipgame/dto/game/MobileGameDTO.java <==
package com.xunlei.niux.data.vipgame.dto.game;

/**
 * 手游DTO，取sdk游戏和cps游戏的共有字段
 * Created by lizeyu on 2016/4/21.
 */
public class MobileGameDTO{
    private String gameId;
    private String gameNo;
    private String gameName;
    private String gameDesc;
    private Integer gameFeature;
    private Integer gameTheme;
    private Integer displayOrder;
    private Integer downloadNum;
    private String packageName;
    private Integer status;
    private String picUrl;
    private String smallPicUrl;
    private String mulPhotoUrl;
    private String downLoadUrl;
    private String shortUrl; //短网址，跳转链接
    private String summary;
    private String appSize;
    private String recommendIndex;
    private Integer mobileGameType;  //cps游戏中，1网游，2单机；sdk游戏，则全部是网游

    private Integer mobileGameTheme;    //手游题材
    private Integer mobileGameLable;    //手游标签


    public String getGameId(){
        return gameId;
    }

    public void setGameId(String gameId){
        this.gameId = gameId;
    }

    public String getGameNo(){
        return gameNo;
    }

    public void setGameNo(String gameNo){
        this.gameNo = gameNo;
    }

    public String getGameName(){
        return gameName;
    }

    public void setGameName(String gameName){
        this.gameName = gameName;
    }

    public String getGameDesc(){
        return gameDesc;
    }

    public void setGameDesc(String gameDesc){
        this.gameDesc = gameDesc;
    }

    public Integer getGameFeature(){
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature){
        this.gameFeature = gameFeature;
    }

    public Integer getGameTheme(){
        return gameTheme;
    }

    public void setGameTheme(Integer gameTheme){
        this.gameTheme = gameTheme;
    }

    public Integer getDisplayOrder(){
        return displayOrder;
    }

    public void setDisplayOrder(Integer displayOrder){
        this.displayOrder = displayOrder;
    }

    public Integer getDownloadNum(){
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum){
        this.downloadNum = downloadNum;
    }

    public String getPackageName(){
        return packageName;
    }

    public void setPackageName(String packageName){
        this.packageName = packageName;
    }

    public Integer getStatus(){
        return status;
    }

    public void setStatus(Integer status){
        this.status = status;
    }

    public String getPicUrl(){
        return picUrl;
    }

    public void setPicUrl(String picUrl){
        this.picUrl = picUrl;
    }

    public String getSmallPicUrl(){
        return smallPicUrl;
    }

    public void setSmallPicUrl(String smallPicUrl){
        this.smallPicUrl = smallPicUrl;
    }

    public String getMulPhotoUrl(){
        return mulPhotoUrl;
    }

    public void setMulPhotoUrl(String mulPhotoUrl){
        this.mulPhotoUrl = mulPhotoUrl;
    }

    public String getDownLoadUrl(){
        return downLoadUrl;
    }

    public void setDownLoadUrl(String downLoadUrl){
        this.downLoadUrl = downLoadUrl;
    }

    public String getSummary(){
        return summary;
    }

    public void setSummary(String summary){
        this.summary = summary;
    }

    public String getAppSize(){
        return appSize;
    }

    public void setAppSize(String appSize){
        this.appSize = appSize;
    }

    public String getRecommendIndex(){
        return recommendIndex;
    }

    public void setRecommendIndex(String recommendIndex){
        this.recommendIndex = recommendIndex;
    }

    public Integer getMobileGameType(){
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType){
        this.mobileGameType = mobileGameType;
    }

    public String getShortUrl(){
        return shortUrl;
    }

    public void setShortUrl(String shortUrl){
        this.shortUrl = shortUrl;
    }

    public Integer getMobileGameTheme(){
        return mobileGameTheme;
    }

    public void setMobileGameTheme(Integer mobileGameTheme){
        this.mobileGameTheme = mobileGameTheme;
    }

    public Integer getMobileGameLable(){
        return mobileGameLable;
    }

    public void setMobileGameLable(Integer mobileGameLable){
        this.mobileGameLable = mobileGameLable;
    }
}
